searchData={"items":[{"type":"module","title":"ROR","doc":"`ROR` is an unofficial client for the [Research Organization Registry (ROR)](https://ror.org) API for Elixir.\nThis top level `ROR` module contains functions for retrieving data via the API.\n\n> The Research Organization Registry (ROR) includes IDs and metadata for more than 110,000 organizations and counting.\n> Registry data is CC0 and openly available via a search interface, REST API, and data dump. Registry updates are curated\n> through a community process and released at least once a month\n\nPlease read ROR's [terms of use](https://ror.org/about/terms/) and do not put excessive load on their API service.","ref":"ROR.html"},{"type":"module","title":"Features - ROR","doc":"* Lookup individual ROR records by ID\n* Search and Quick Search based on names or record attributes\n* Paging and filters for queries and lists\n* Match text to records, possibly identifying an organisation from existing data\n* Records are returned as typed structs (slightly different to the ROR JSON responses, but containing all the information)\n* Client ID authentication is supported and optional\n* API service heartbeat checks\n* (This is an early version and only contains the basics so far)\n\n You may not need to use the other ROR modules directly at all, but here are a few that might be handy:\n\n* `ROR.Client` presents a lower-level way to retrieve data, and returns maps based on the literal ROR JSON responses.\n* `ROR.Organization` contains a struct and utilities for the main ROR organization record\n* `ROR.Results` is an enumerable struct that contains both Organizations and metadata\n* `ROR.Matches` is another enumerable struct, which contains results from affiliation searches","ref":"ROR.html#module-features"},{"type":"module","title":"Defining Filters - ROR","doc":"Filters are used to fine-tune results before they are returned.\n\n> Results can be filtered by record status, organization type, ISO 3166 country code, country name, continent code, and continent name.\n\nIn the `ROR` module they are defined directly using either a keyword list\n\n    iex> ROR.list!(filter: [type: :government])\n\nor by creating a `ROR.Filter` struct, and passing that\n\n    iex> my_filter = ROR.Filter.new(status: :inactive, types: :facility)\n    ...> ROR.list!(filter: my_filter)\n\nYou can read more about filters in the [official ROR docs](https://ror.readme.io/v2/docs/api-filtering)","ref":"ROR.html#module-defining-filters"},{"type":"module","title":"Authentication - ROR","doc":"The ROR API does not require authentication, but it can be used to permit heavier usage. You must register on the ROR\nwebsite for a key/token, and then include that in calls using the `:client_id` option like this:\n\n    iex> ROR.get!(\"https://ror.org/04h699437\", client_id: \"client ID goes here\")","ref":"ROR.html#module-authentication"},{"type":"module","title":"Paging - ROR","doc":"API calls that return multiple results will limit them to pages of 20 organizations at a time, and default to page 1.\n\nYou can specify pages using the `:page` option.\n\n    iex> ROR.list!(page: 20)\n\nYou can read more about paging in the [official ROR docs](https://ror.readme.io/v2/docs/api-paging)","ref":"ROR.html#module-paging"},{"type":"module","title":"Results and Matches - ROR","doc":"Results are returned as `ROR.Results` and `ROR.Matches` structs which contain a list of `ROR.Organization` structs\nand some metadata. They are enumerable, so you can use `Enum` functions on them directly.\n\nSo, iterating through the items in the Results struct and iterating directly are equivalent\n\n    iex> results = ROR.list!()\n    ...> # this\n    ...> Enum.map(results.items, fn o -> o.id end)\n    ...> # can also be done like this\n    ...> Enum.map(results, fn o -> o.id end)","ref":"ROR.html#module-results-and-matches"},{"type":"module","title":"Stringifying ROR structs - ROR","doc":"Many structs used by the ROR library can be converted to strings, and converted automatically if interpolated inside\nother strings. This can be useful when logging and debugging.\n\nInformation will be lost, and the process is one-way - you cannot convert them back to structs from strings.\n\n    iex> org = ROR.get!(\"https://ror.org/04h699437\")\n    ...> to_string(org)\n    \"https://ror.org/04h699437\"\n    iex> org = ROR.get!(\"https://ror.org/04h699437\")\n    ...> to_string(org.admin)\n    \"2018-11-14, 2024-12-11\"","ref":"ROR.html#module-stringifying-ror-structs"},{"type":"module","title":"Examples - ROR","doc":"","ref":"ROR.html#module-examples"},{"type":"module","title":"Retrieving data about an organization using its ROR ID - ROR","doc":"iex> org = ROR.get!(\"https://ror.org/04h699437\")\n    ...> org.domains\n    [\"le.ac.uk\"]","ref":"ROR.html#module-retrieving-data-about-an-organization-using-its-ror-id"},{"type":"module","title":"List ROR records, specifying a page and a filter - ROR","doc":"iex> ROR.list!(page: 15, filter: [type: :government])\n    ...> |> Enum.map(fn org -> org.id end)\n    ...> |> Enum.count()\n    20","ref":"ROR.html#module-list-ror-records-specifying-a-page-and-a-filter"},{"type":"module","title":"A quick search - ROR","doc":"iex> a =\n    ...>   ROR.quick_search!(\"University of Manchester\")\n    ...>   |> Enum.take(1)\n    ...>   |> List.first()\n    ...> \n    ...> a.established\n    1824","ref":"ROR.html#module-a-quick-search"},{"type":"module","title":"An affiliation search for strong match or nil, also showing off the string conversion feature - ROR","doc":"iex> org = ROR.chosen_organization!(\"CERN\")\n    ...> Enum.map(org.names, &to_string/1)\n    [\n      \"CERN\",\n      \"European Organization for Nuclear Research\",\n      \"Europäische Organisation für Kernforschung\",\n      \"Organisation européenne pour la recherche nucléaire\"\n    ]","ref":"ROR.html#module-an-affiliation-search-for-strong-match-or-nil-also-showing-off-the-string-conversion-feature"},{"type":"function","title":"ROR.api_versions/0","doc":"Returns a list of supported API versions.","ref":"ROR.html#api_versions/0"},{"type":"function","title":"Example - ROR.api_versions/0","doc":"iex> ROR.api_versions()\n    [\"v2.1\"]","ref":"ROR.html#api_versions/0-example"},{"type":"function","title":"ROR.chosen_organization!/2","doc":"Attempts to identify **one** organization that has been chosen as a close match for the string, or returns nil if there\n  is any ambiguity.\n\nResults cannot be paged or filtered.\n\nAn exception will be raised if matches cannot be returned.","ref":"ROR.html#chosen_organization!/2"},{"type":"function","title":"Options - ROR.chosen_organization!/2","doc":"* `api_url`: The base URL (optional)\n  * `client_id`: ROR authentication token (optional)","ref":"ROR.html#chosen_organization!/2-options"},{"type":"function","title":"Example - ROR.chosen_organization!/2","doc":"iex> ROR.chosen_organization!(\n    ...>   \"Department of Civil and Industrial Engineering, University of Pisa, Largo Lucio Lazzarino 2, Pisa 56126, Italy\"\n    ...> )","ref":"ROR.html#chosen_organization!/2-example"},{"type":"function","title":"ROR.exists?/2","doc":"Check if a single, specified record is available via the API, returning true or false.\n\nThe ID can be any valid format: `https://ror.org/04h699437`, `ror.org/04h699437` or `04h699437`\n\nFalse will be returned if the ID is invalid, or the URL incorrect, or the record simply isn't available.","ref":"ROR.html#exists?/2"},{"type":"function","title":"Options - ROR.exists?/2","doc":"* `api_url`: The base URL (optional)\n  * `client_id`: ROR authentication token (optional)","ref":"ROR.html#exists?/2-options"},{"type":"function","title":"Example - ROR.exists?/2","doc":"iex> ROR.exists?(\"https://ror.org/04h699437\")\n    true","ref":"ROR.html#exists?/2-example"},{"type":"function","title":"ROR.get!/2","doc":"Retrieve a single Organization record using its ROR ID.\n\nThe ID can be any valid format: `https://ror.org/04h699437`, `ror.org/04h699437` or `04h699437`\n\nAn exception will be raised if an Organization cannot be returned\n\nYou can read more about getting a single record in the [official ROR docs](https://ror.readme.io/v2/docs/api-single)","ref":"ROR.html#get!/2"},{"type":"function","title":"Options - ROR.get!/2","doc":"* `api_url`: The base URL (optional)\n  * `client_id`: ROR authentication token (optional)","ref":"ROR.html#get!/2-options"},{"type":"function","title":"Example - ROR.get!/2","doc":"iex> ROR.get!(\"https://ror.org/04h699437\")","ref":"ROR.html#get!/2-example"},{"type":"function","title":"ROR.heartbeat?/1","doc":"Returns true if the API is available","ref":"ROR.html#heartbeat?/1"},{"type":"function","title":"Options - ROR.heartbeat?/1","doc":"* `api_url`: The base URL (optional)","ref":"ROR.html#heartbeat?/1-options"},{"type":"function","title":"Example - ROR.heartbeat?/1","doc":"iex> ROR.heartbeat?()\n    true\n    iex> ROR.heartbeat?(api_url: \"https://incorrect.example.com/organizations\")\n    false","ref":"ROR.html#heartbeat?/1-example"},{"type":"function","title":"ROR.identify!/2","doc":"Attempts to find organizations that match the provided string, with levels of confidence that an organization has\n been identified. Returns a Matches struct, which contains a list of Match records, each with an Organization.\n\nThis API call is potentially useful for finding the correct ROR organization record for existing data, but must be used\n  carefully.\n\nResults cannot be paged or filtered.\n\nAn exception will be raised if matches cannot be returned.\n\nYou can read more about affiliation queries in the [official ROR docs](https://ror.readme.io/v2/docs/api-affiliation)","ref":"ROR.html#identify!/2"},{"type":"function","title":"Options - ROR.identify!/2","doc":"* `api_url`: The base URL (optional)\n  * `client_id`: ROR authentication token (optional)","ref":"ROR.html#identify!/2-options"},{"type":"function","title":"Example - ROR.identify!/2","doc":"iex> ROR.identify!(\n    ...>   \"Department of Civil and Industrial Engineering, University of Pisa, Largo Lucio Lazzarino 2, Pisa 56126, Italy\"\n    ...> )","ref":"ROR.html#identify!/2-example"},{"type":"function","title":"ROR.list!/1","doc":"Returns a Results struct that contains Organization structs.\n\nAn exception will be raised if a list of organizations data cannot be returned\n\nYou can read more about getting a list of records in the [official ROR docs](https://ror.readme.io/v2/docs/api-list)","ref":"ROR.html#list!/1"},{"type":"function","title":"Options - ROR.list!/1","doc":"* `api_url`: The base URL (optional)\n  * `client_id`: ROR authentication token (optional)\n  * `page`: a page number (optional)\n  * `filter`: filter options, or a Filter Struct (optional)\n  * `all_status`: set to `true` to return active, inactive and withdrawn organizations (optional)","ref":"ROR.html#list!/1-options"},{"type":"function","title":"Example - ROR.list!/1","doc":"iex> ROR.list!(page: 3, filter: [type: :government])","ref":"ROR.html#list!/1-example"},{"type":"function","title":"ROR.quick_search!/2","doc":"Searches names and external_ids in the ROR database and returns a Results struct that has a list of Organization structs.\n\nThis style of search is relatively quick and simple, and suitable for things like auto-suggestion lookups.\n\nAn exception will be raised if results cannot be returned\n\nYou can read more about querying records in the [official ROR docs](https://ror.readme.io/v2/docs/api-query)","ref":"ROR.html#quick_search!/2"},{"type":"function","title":"Options - ROR.quick_search!/2","doc":"* `api_url`: The base URL (optional)\n  * `client_id`: ROR authentication token (optional)\n  * `page`: a page number (optional)\n  * `filter`: filter options, or a Filter Struct (optional)\n  * `all_status`: set to `true` to return active, inactive and withdrawn organizations (optional)","ref":"ROR.html#quick_search!/2-options"},{"type":"function","title":"Example - ROR.quick_search!/2","doc":"iex> ROR.quick_search!(\"'New York'\", page: 1)","ref":"ROR.html#quick_search!/2-example"},{"type":"function","title":"ROR.search!/2","doc":"Searches all fields in the ROR database if given a simple string, or allows use of ElasticSearch-style search queries.\nReturns a Results struct that has a list of Organization structs.\n\nThis API call is slower and more resource-intensive than `quick_search/2` but allows more precision.\n\nAn exception will be raised if results cannot be returned.\n\nYou can read more about advanced queries in the [official ROR docs](https://ror.readme.io/v2/docs/api-advanced-query)","ref":"ROR.html#search!/2"},{"type":"function","title":"Options - ROR.search!/2","doc":"* `api_url`: The base URL (optional)\n  * `client_id`: ROR authentication token (optional)\n  * `page`: a page number (optional)\n  * `filter`: filter options, or a Filter Struct (optional)\n  * `all_status`: set to `true` to return active, inactive and withdrawn organizations (optional)","ref":"ROR.html#search!/2-options"},{"type":"function","title":"Example - ROR.search!/2","doc":"iex> ROR.search!(\"'Harvard University'\", page: 1)\n    ...> ROR.search!(\"names.value:Cornell AND locations.geonames_details.name:Ithaca\")","ref":"ROR.html#search!/2-example"},{"type":"module","title":"ROR.Admin","doc":"Functions for extracting and using Admin data from a ROR Organization record\n\nThe admin struct is not the same as the original ROR data: it's flatter, with only one level of fields.","ref":"ROR.Admin.html"},{"type":"function","title":"ROR.Admin.extract/1","doc":"Extracts an Admin struct from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Admin.html#extract/1"},{"type":"function","title":"Example - ROR.Admin.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Admin.extract(record)\n    %ROR.Admin{\n      created_at: ~D[2020-04-25],\n      created_schema: \"1.0\",\n      updated_at: ~D[2022-10-18],\n      updated_schema: \"2.0\"\n    }","ref":"ROR.Admin.html#extract/1-example"},{"type":"type","title":"ROR.Admin.t/0","doc":"","ref":"ROR.Admin.html#t:t/0"},{"type":"module","title":"ROR.Client","doc":"Low-level functions for using the ROR REST API, returning maps parsed from the API's JSON responses.\n\nIt's normally better to use the `ROR` module, unless you want to use the decoded JSON responses from the API, or\n  pass parameters and headers directly.\n\nParameters are passed as a map or keyword list of strings. They do not need to be URL-encoded (ROR will do that) but you must manually escape\n  any ElasticSearch symbols. IDs are normalized. Things like changing the API base URL must be done by passing options\n  to the `Req` HTTP library using the `:http` option.","ref":"ROR.Client.html"},{"type":"function","title":"ROR.Client.affiliation!/2","doc":"Attempts to find organizations that match the provided string, with levels of confidence that an organization has\n been identified. Returns a map of match results, each with an organization map.\n\nThis API call is potentially useful for finding the correct ROR organization record for existing data, but must be used\n  carefully.\n\nResults cannot be paged or filtered.\n\nAn exception will be raised if matches cannot be returned.\n\nYou can read more about affiliation queries in the [official ROR docs](https://ror.readme.io/v2/docs/api-affiliation)","ref":"ROR.Client.html#affiliation!/2"},{"type":"function","title":"Options - ROR.Client.affiliation!/2","doc":"* `params`: A map or keyword list of HTTP params that is passed to `Req` and merged with defaults (optional)\n  * `headers`: A map or keyword list of HTTP headers that is passed to `Req` and merged with defaults (optional)\n  * `http`: A map or keyword list of `Req` options that is passed to `Req` and merged with defaults (optional)","ref":"ROR.Client.html#affiliation!/2-options"},{"type":"function","title":"Example - ROR.Client.affiliation!/2","doc":"iex> ROR.affiliation!(\n    ...>   \"Department of Civil and Industrial Engineering, University of Pisa, Largo Lucio Lazzarino 2, Pisa 56126, Italy\"\n    ...> )","ref":"ROR.Client.html#affiliation!/2-example"},{"type":"function","title":"ROR.Client.get!/2","doc":"Retrieve a single organization record as a map using its ROR ID.\n\nThe ID can be any valid format: `https://ror.org/04h699437`, `ror.org/04h699437` or `04h699437`\n\nAn exception will be raised if data cannot be returned\n\nYou can read more about getting a single record in the [official ROR docs](https://ror.readme.io/v2/docs/api-single)","ref":"ROR.Client.html#get!/2"},{"type":"function","title":"Options - ROR.Client.get!/2","doc":"* `params`: A map or keyword list of HTTP params that is passed to `Req` and merged with defaults (optional)\n  * `headers`: A map or keyword list of HTTP headers that is passed to `Req` and merged with defaults (optional)\n  * `http`: A map or keyword list of `Req` options that is passed to `Req` and merged with defaults (optional)","ref":"ROR.Client.html#get!/2-options"},{"type":"function","title":"Example - ROR.Client.get!/2","doc":"iex> ROR.Client.get!(\"https://ror.org/04h699437\")","ref":"ROR.Client.html#get!/2-example"},{"type":"function","title":"ROR.Client.list!/1","doc":"Returns a map that contains organization records.\n\nAn exception will be raised if a list of organizations data cannot be returned\n\nYou can read more about getting a list of records in the [official ROR docs](https://ror.readme.io/v2/docs/api-list)","ref":"ROR.Client.html#list!/1"},{"type":"function","title":"Options - ROR.Client.list!/1","doc":"* `params`: A map or keyword list of HTTP params that is passed to `Req` and merged with defaults (optional)\n  * `headers`: A map or keyword list of HTTP headers that is passed to `Req` and merged with defaults (optional)\n  * `http`: A map or keyword list of `Req` options that is passed to `Req` and merged with defaults (optional)","ref":"ROR.Client.html#list!/1-options"},{"type":"function","title":"Example - ROR.Client.list!/1","doc":"iex> ROR.Client.list!(params: [page: \"3\", filter: \"type:government\"])","ref":"ROR.Client.html#list!/1-example"},{"type":"function","title":"ROR.Client.query!/2","doc":"Searches names and external_ids in the ROR database and returns a map that has a list of organization records.\n\nThis style of search is relatively quick and simple, and suitable for things like auto-suggestion lookups.\n\nAn exception will be raised if results cannot be returned\n\nYou can read more about querying records in the [official ROR docs](https://ror.readme.io/v2/docs/api-query)","ref":"ROR.Client.html#query!/2"},{"type":"function","title":"Options - ROR.Client.query!/2","doc":"* `params`: A map or keyword list of HTTP params that is passed to `Req` and merged with defaults (optional)\n  * `headers`: A map or keyword list of HTTP headers that is passed to `Req` and merged with defaults (optional)\n  * `http`: A map or keyword list of `Req` options that is passed to `Req` and merged with defaults (optional)","ref":"ROR.Client.html#query!/2-options"},{"type":"function","title":"Example - ROR.Client.query!/2","doc":"iex> ROR.Client.query!(\"'New York'\", params: [page: \"3\"])","ref":"ROR.Client.html#query!/2-example"},{"type":"function","title":"ROR.Client.query_advanced!/2","doc":"Searches all fields in the ROR database if given a simple string, or allows use of ElasticSearch-style search queries.\nReturns a map that has a list of organization records (also as maps).\n\nThis API call is slower and more resource-intensive than `query/2` but allows more precision.\n\nAn exception will be raised if results cannot be returned.\n\nYou can read more about advanced queries in the [official ROR docs](https://ror.readme.io/v2/docs/api-advanced-query)","ref":"ROR.Client.html#query_advanced!/2"},{"type":"function","title":"Options - ROR.Client.query_advanced!/2","doc":"* `params`: A map or keyword list of HTTP params that is passed to `Req` and merged with defaults (optional)\n  * `headers`: A map or keyword list of HTTP headers that is passed to `Req` and merged with defaults (optional)\n  * `http`: A map or keyword list of `Req` options that is passed to `Req` and merged with defaults (optional)","ref":"ROR.Client.html#query_advanced!/2-options"},{"type":"function","title":"Example - ROR.Client.query_advanced!/2","doc":"iex> ROR.Client.query_advanced!(\"'Harvard University'\", params: [page: \"1\"])\n    ...> \n    ...> ROR.Client.query_advanced!(\n    ...>   \"names.value:Cornell AND locations.geonames_details.name:Ithaca\"\n    ...> )","ref":"ROR.Client.html#query_advanced!/2-example"},{"type":"module","title":"ROR.Domain","doc":"Functions for extracting and using Domain data from a ROR Organization record\n\nDomains are a list of strings.","ref":"ROR.Domain.html"},{"type":"function","title":"ROR.Domain.extract/1","doc":"Extracts list of domain name strings from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Domain.html#extract/1"},{"type":"function","title":"Example - ROR.Domain.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Domain.extract(record)\n    [\"universityofcalifornia.edu\"]","ref":"ROR.Domain.html#extract/1-example"},{"type":"function","title":"ROR.Domain.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.Domain.html#vocab/0"},{"type":"module","title":"ROR.ExternalID","doc":"Functions for extracting and using ExternalID data from a ROR Organization record","ref":"ROR.ExternalID.html"},{"type":"function","title":"ROR.ExternalID.extract/1","doc":"Extracts a list of ExternalID structs from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.ExternalID.html#extract/1"},{"type":"function","title":"Example - ROR.ExternalID.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.ExternalID.extract(record)\n    [\n      %ROR.ExternalID{\n        type: :fundref,\n        preferred: \"100005595\",\n        all: [\"100005595\", \"100009350\", \"100004802\", \"100010574\", \"100005188\", \"100005192\"]\n      },\n      %ROR.ExternalID{\n        type: :grid,\n        preferred: \"grid.30389.31\",\n        all: [\"grid.30389.31\"]\n      },\n      %ROR.ExternalID{type: :isni, preferred: nil, all: [\"0000 0001 2348 0690\"]}\n    ]","ref":"ROR.ExternalID.html#extract/1-example"},{"type":"type","title":"ROR.ExternalID.t/0","doc":"","ref":"ROR.ExternalID.html#t:t/0"},{"type":"function","title":"ROR.ExternalID.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.ExternalID.html#vocab/0"},{"type":"module","title":"ROR.Filter","doc":"A structure for building simple ROR Filter strings","ref":"ROR.Filter.html"},{"type":"function","title":"ROR.Filter.new/1","doc":"Creates a new Filter struct from a map or keyword list.\n\nKeys that can be passed are: `:status`, `:types`, `:country_code`, `:country_name`, `:continent_code`, `:continent_name`\n  and also `:type`, which is corrected to `:types`.\n\nPassing an existing Filter struct returns the same struct","ref":"ROR.Filter.html#new/1"},{"type":"function","title":"Example - ROR.Filter.new/1","doc":"iex> ROR.Filter.new(types: \"funder\", country_code: \"DE\")\n    %ROR.Filter{\n      status: nil,\n      types: \"funder\",\n      country_code: \"DE\",\n      country_name: nil,\n      continent_code: nil,\n      continent_name: nil\n    }","ref":"ROR.Filter.html#new/1-example"},{"type":"type","title":"ROR.Filter.t/0","doc":"","ref":"ROR.Filter.html#t:t/0"},{"type":"function","title":"ROR.Filter.to_ror_param/1","doc":"Converts a Filter struct to a ROR filter string","ref":"ROR.Filter.html#to_ror_param/1"},{"type":"function","title":"Example - ROR.Filter.to_ror_param/1","doc":"iex> ROR.Filter.new(types: \"funder\", country_code: \"DE\")\n    ...> |> ROR.Filter.to_ror_param()\n    \"types:funder,locations.geonames_details.country_code:DE\"","ref":"ROR.Filter.html#to_ror_param/1-example"},{"type":"module","title":"ROR.ID","doc":"Functions for extracting and using Admin data from a ROR Organization record\n\nIDs are simply a string","ref":"ROR.ID.html"},{"type":"function","title":"ROR.ID.extract/1","doc":"Extracts an ID string from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.ID.html#extract/1"},{"type":"function","title":"Example - ROR.ID.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.ID.extract(record)\n    \"https://ror.org/00pjdza24\"","ref":"ROR.ID.html#extract/1-example"},{"type":"function","title":"ROR.ID.minimize/1","doc":"Takes any variant of the ROR ID and returns only the record ID fragment\n\n    iex> ID.minimize(\"https://ror.org/00pjdza24\")\n    \"00pjdza24\"","ref":"ROR.ID.html#minimize/1"},{"type":"function","title":"ROR.ID.normalize/1","doc":"Takes any ID variant and returns a full ID\n\n    iex> ID.normalize(\"00pjdza24\")\n    \"https://ror.org/00pjdza24\"","ref":"ROR.ID.html#normalize/1"},{"type":"function","title":"ROR.ID.path/1","doc":"Return a URL path for the ID\n\n    iex> ID.minimize(\"https://ror.org/00pjdza24\")\n    \"/00pjdza24\"","ref":"ROR.ID.html#path/1"},{"type":"function","title":"ROR.ID.valid?/1","doc":"Returns true if the ID is valid, false otherwise\n\n    iex> ID.valid?(\"https://ror.org/00pjdza24\")\n    true","ref":"ROR.ID.html#valid?/1"},{"type":"module","title":"ROR.Link","doc":"Functions for extracting and using Link data from a ROR Organization record","ref":"ROR.Link.html"},{"type":"function","title":"ROR.Link.extract/1","doc":"Extracts a list of Link structs from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Link.html#extract/1"},{"type":"function","title":"Example - ROR.Link.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Link.extract(record)\n    [\n      %ROR.Link{type: :website, value: \"http://www.universityofcalifornia.edu/\"},\n      %ROR.Link{\n        type: :wikipedia,\n        value: \"http://en.wikipedia.org/wiki/University_of_California\"\n      }\n    ]","ref":"ROR.Link.html#extract/1-example"},{"type":"type","title":"ROR.Link.t/0","doc":"","ref":"ROR.Link.html#t:t/0"},{"type":"function","title":"ROR.Link.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.Link.html#vocab/0"},{"type":"module","title":"ROR.Location","doc":"Functions for extracting and using Admin data from a ROR Organization record\n\nLocation structs are a little different to the ROR JSON data - they're flattened, with a type - but contain the same\n  information.","ref":"ROR.Location.html"},{"type":"function","title":"ROR.Location.extract/1","doc":"Extracts a list of Location structs from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Location.html#extract/1"},{"type":"function","title":"Example - ROR.Location.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Location.extract(record)\n    [\n      %ROR.Location{\n        type: :geonames,\n        id: 5_378_538,\n        continent_name: nil,\n        continent_code: nil,\n        country_code: \"US\",\n        country_name: \"United States\",\n        country_subdivision_code: nil,\n        country_subdivision_name: nil,\n        latitude: 37.802168,\n        longitude: -122.271281,\n        name: \"Oakland\"\n      }\n    ]","ref":"ROR.Location.html#extract/1-example"},{"type":"type","title":"ROR.Location.t/0","doc":"","ref":"ROR.Location.html#t:t/0"},{"type":"function","title":"ROR.Location.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.Location.html#vocab/0"},{"type":"module","title":"ROR.Match","doc":"Functions for extracting and using Match data from a ROR Organization record\n\nEach Organization with a match from the `ROR.identify!/2` function is wrapped up in a Match struct","ref":"ROR.Match.html"},{"type":"function","title":"ROR.Match.extract/1","doc":"Extracts Match records from the JSON returned by an affiliation API call","ref":"ROR.Match.html#extract/1"},{"type":"type","title":"ROR.Match.t/0","doc":"","ref":"ROR.Match.html#t:t/0"},{"type":"function","title":"ROR.Match.vocab/0","doc":"List possible types of match","ref":"ROR.Match.html#vocab/0"},{"type":"module","title":"ROR.Matches","doc":"A structure for storing organization match results from Identify/Affiliation searches\n\nMatches is the equivalent to the `ROR.Results` struct when checking for affiliation matches with `ROR.identify!/2`\n\nThis struct supports the `Enum` protocol, so you can directly iterate the matches within","ref":"ROR.Matches.html"},{"type":"function","title":"ROR.Matches.chosen/1","doc":"Returns a chosen Match (a reliably high-rated match) or nil if one has not been found","ref":"ROR.Matches.html#chosen/1"},{"type":"function","title":"ROR.Matches.chosen_organization/1","doc":"Returns a chosen Organization (from within a reliably high-rated match) or nil if one has not been found","ref":"ROR.Matches.html#chosen_organization/1"},{"type":"function","title":"ROR.Matches.extract/1","doc":"Extract a Matches struct, containing Match structs and Organizations, from the JSON returned by the ROR affiliation API.\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Matches.html#extract/1"},{"type":"function","title":"ROR.Matches.matches/1","doc":"Lists Matches","ref":"ROR.Matches.html#matches/1"},{"type":"function","title":"ROR.Matches.number_of_matches/1","doc":"Returns the total number of matches","ref":"ROR.Matches.html#number_of_matches/1"},{"type":"type","title":"ROR.Matches.t/0","doc":"","ref":"ROR.Matches.html#t:t/0"},{"type":"module","title":"ROR.Name","doc":"Functions for extracting and using Name data from a ROR Organization record","ref":"ROR.Name.html"},{"type":"function","title":"ROR.Name.extract/1","doc":"Extracts a list of Name structs from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Name.html#extract/1"},{"type":"function","title":"Example - ROR.Name.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Name.extract(record)\n    [\n      %ROR.Name{lang: \"en\", types: [:acronym], value: \"UC\"},\n      %ROR.Name{lang: \"en\", types: [:alias], value: \"UC System\"},\n      %ROR.Name{\n        lang: \"en\",\n        types: [:ror_display, :label],\n        value: \"University of California System\"\n      },\n      %ROR.Name{lang: \"fr\", types: [:label], value: \"Université de Californie\"}\n    ]","ref":"ROR.Name.html#extract/1-example"},{"type":"type","title":"ROR.Name.t/0","doc":"","ref":"ROR.Name.html#t:t/0"},{"type":"function","title":"ROR.Name.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.Name.html#vocab/0"},{"type":"module","title":"ROR.Organization","doc":"Functions for extracting and using Organization data from a ROR Organization record","ref":"ROR.Organization.html"},{"type":"function","title":"ROR.Organization.extract/1","doc":"Extracts an Organization struct from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Organization.html#extract/1"},{"type":"function","title":"Example - ROR.Organization.extract/1","doc":"iex(12)> ROR.Organization.extract(record)\n    %ROR.Organization{\n      id: \"https://ror.org/00pjdza24\",\n      admin: %ROR.Admin{\n        created_at: ~D[2020-04-25],\n        created_schema: \"1.0\",\n        updated_at: ~D[2022-10-18],\n        updated_schema: \"2.0\"\n      },\n      domains: [\"universityofcalifornia.edu\"],\n      established: 1868,\n      external_ids: [\n        %ROR.ExternalID{\n          type: :fundref,\n          preferred: \"100005595\",\n          all: [\"100005595\", \"100009350\", \"100004802\", \"100010574\", \"100005188\", \"100005192\"]\n        },\n        %ROR.ExternalID{\n          type: :grid,\n          preferred: \"grid.30389.31\",\n          all: [\"grid.30389.31\"]\n        },\n        %ROR.ExternalID{type: :isni, preferred: nil, all: [\"0000 0001 2348 0690\"]}\n      ],\n      links: [\n        %ROR.Link{type: :website, value: \"http://www.universityofcalifornia.edu/\"},\n        %ROR.Link{\n          type: :wikipedia,\n          value: \"http://en.wikipedia.org/wiki/University_of_California\"\n        }\n      ],\n      locations: [\n        %ROR.Location{\n          type: :geonames,\n          id: 5_378_538,\n          continent_name: nil,\n          continent_code: nil,\n          country_code: \"US\",\n          country_name: \"United States\",\n          country_subdivision_code: nil,\n          country_subdivision_name: nil,\n          latitude: 37.802168,\n          longitude: -122.271281,\n          name: \"Oakland\"\n        }\n      ],\n      names: [\n        %ROR.Name{lang: \"en\", types: [:acronym], value: \"UC\"},\n        %ROR.Name{lang: \"en\", types: [:alias], value: \"UC System\"},\n        %ROR.Name{\n          lang: \"en\",\n          types: [:ror_display, :label],\n          value: \"University of California System\"\n        },\n        %ROR.Name{lang: \"fr\", types: [:label], value: \"Université de Californie\"}\n      ],\n      relationships: [\n        %ROR.Relationship{\n          id: \"https://ror.org/02jbv0t02\",\n          label: \"Lawrence Berkeley National Laboratory\",\n          type: :related\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/03yrm5c26\",\n          label: \"California Digital Library\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/00zv0wd17\",\n          label: \"Center for Information Technology Research in the Interest of Society\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/03t0t6y08\",\n          label: \"University of California Division of Agriculture and Natural Resources\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/01an7q238\",\n          label: \"University of California, Berkeley\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/05rrcem69\",\n          label: \"University of California, Davis\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/04gyf1771\",\n          label: \"University of California, Irvine\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/046rm7j60\",\n          label: \"University of California, Los Angeles\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/00d9ah105\",\n          label: \"University of California, Merced\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/03nawhv43\",\n          label: \"University of California, Riverside\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/0168r3w48\",\n          label: \"University of California, San Diego\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/043mz5j54\",\n          label: \"University of California, San Francisco\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/02t274463\",\n          label: \"University of California, Santa Barbara\",\n          type: :child\n        },\n        %ROR.Relationship{\n          id: \"https://ror.org/03s65by71\",\n          label: \"University of California, Santa Cruz\",\n          type: :child\n        }\n      ],\n      status: :active,\n      types: [:education]\n    }","ref":"ROR.Organization.html#extract/1-example"},{"type":"function","title":"ROR.Organization.full_id/1","doc":"Returns the full ID from an Organization","ref":"ROR.Organization.html#full_id/1"},{"type":"function","title":"ROR.Organization.id/1","doc":"Returns the ID from an Organization","ref":"ROR.Organization.html#id/1"},{"type":"type","title":"ROR.Organization.t/0","doc":"","ref":"ROR.Organization.html#t:t/0"},{"type":"module","title":"ROR.Relationship","doc":"Functions for extracting and using Relationship data from a ROR Organization record","ref":"ROR.Relationship.html"},{"type":"function","title":"ROR.Relationship.extract/1","doc":"Extracts a list of Relationship structs from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Relationship.html#extract/1"},{"type":"function","title":"Example - ROR.Relationship.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Relationship.extract(record)\n    [\n      %ROR.Relationship{\n        id: \"https://ror.org/02jbv0t02\",\n        label: \"Lawrence Berkeley National Laboratory\",\n        type: :related\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/03yrm5c26\",\n        label: \"California Digital Library\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/00zv0wd17\",\n        label: \"Center for Information Technology Research in the Interest of Society\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/03t0t6y08\",\n        label: \"University of California Division of Agriculture and Natural Resources\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/01an7q238\",\n        label: \"University of California, Berkeley\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/05rrcem69\",\n        label: \"University of California, Davis\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/04gyf1771\",\n        label: \"University of California, Irvine\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/046rm7j60\",\n        label: \"University of California, Los Angeles\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/00d9ah105\",\n        label: \"University of California, Merced\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/03nawhv43\",\n        label: \"University of California, Riverside\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/0168r3w48\",\n        label: \"University of California, San Diego\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/043mz5j54\",\n        label: \"University of California, San Francisco\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/02t274463\",\n        label: \"University of California, Santa Barbara\",\n        type: :child\n      },\n      %ROR.Relationship{\n        id: \"https://ror.org/03s65by71\",\n        label: \"University of California, Santa Cruz\",\n        type: :child\n      }\n    ]","ref":"ROR.Relationship.html#extract/1-example"},{"type":"type","title":"ROR.Relationship.t/0","doc":"","ref":"ROR.Relationship.html#t:t/0"},{"type":"function","title":"ROR.Relationship.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.Relationship.html#vocab/0"},{"type":"module","title":"ROR.Results","doc":"A structure and tools for search and list results\n\nThis struct supports the `Enum` protocol, so you can directly iterate the Organizations within.","ref":"ROR.Results.html"},{"type":"function","title":"ROR.Results.extract/1","doc":"Extract a Results struct, containing Organizations, from the JSON returned by the ROR query and list API.\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Results.html#extract/1"},{"type":"function","title":"ROR.Results.number_of_results/1","doc":"Returns **total** number of results (not just the set of up to 20 returned in the current page)","ref":"ROR.Results.html#number_of_results/1"},{"type":"function","title":"ROR.Results.organizations/1","doc":"Returns a list of all Organizations in the Results","ref":"ROR.Results.html#organizations/1"},{"type":"function","title":"ROR.Results.orgs/1","doc":"Returns a list of all Organizations in the Results but you're less likely to use an 's' by mistake","ref":"ROR.Results.html#orgs/1"},{"type":"type","title":"ROR.Results.t/0","doc":"","ref":"ROR.Results.html#t:t/0"},{"type":"function","title":"ROR.Results.time_taken/1","doc":"Returns time taken by query on the API service (ms)","ref":"ROR.Results.html#time_taken/1"},{"type":"module","title":"ROR.Status","doc":"Functions for extracting and using Status data from a ROR Organization record\n\nAn Organization's status is one of three atoms: `:active`, `:inactive` and `:withdrawn`\n\nBy default only `:active` Organizations are returned by the ROR API.","ref":"ROR.Status.html"},{"type":"function","title":"ROR.Status.extract/1","doc":"Extracts the status from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Status.html#extract/1"},{"type":"function","title":"Example - ROR.Status.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Status.extract(record)\n    :active","ref":"ROR.Status.html#extract/1-example"},{"type":"function","title":"ROR.Status.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.Status.html#vocab/0"},{"type":"module","title":"ROR.Type","doc":"Functions for extracting and using Type data from a ROR Organization record\n\nAn Organization's type is one or more atoms: `:education`, `:funder`, `:healthcare`, `:company`, `:archive`, `:nonprofit`, `:government`,\n`:facility`, and `:other`","ref":"ROR.Type.html"},{"type":"function","title":"ROR.Type.extract/1","doc":"Extracts list of types from the decoded JSON of a ROR Organization record\n\nIf you are retrieving records via the `ROR` module and the REST API you will not need to use this function yourself.","ref":"ROR.Type.html#extract/1"},{"type":"function","title":"Example - ROR.Type.extract/1","doc":"iex> record = File.read!(\"test/support/static/example_org.json\") |> Jason.decode!()\n    ...> ROR.Type.extract(record)\n    [:education]","ref":"ROR.Type.html#extract/1-example"},{"type":"function","title":"ROR.Type.vocab/0","doc":"Lists the allowed terms or types for this data structure, as atoms.","ref":"ROR.Type.html#vocab/0"},{"type":"extras","title":"ROR","doc":"# ROR\n\n`ROR` is an unofficial client for the [Research Organization Registry (ROR)](https://ror.org) API for Elixir.\n\n> The Research Organization Registry (ROR) includes IDs and metadata for more than 110,000 organizations and counting.\n> Registry data is CC0 and openly available via a search interface, REST API, and data dump. Registry updates are curated\n> through a community process and released at least once a month\n\nPlease read ROR's [terms of use](https://ror.org/about/terms/) and do not put excessive load on their API service. \n\n[![Hex pm](http://img.shields.io/hexpm/v/ror.svg?style=flat)](https://hex.pm/packages/ror)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](http://hexdocs.pm/ror/)\n![Github Elixir CI](https://github.com/Digital-Identity-Labs/ror/workflows/ElixirCI/badge.svg)\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fraw.githubusercontent.com%2FDigital-Identity-Labs%2Fror%2Fmain%2Fror_notebook.livemd)","ref":"readme.html"},{"type":"extras","title":"Features - ROR","doc":"* Lookup individual ROR records by ID\n* Search and Quick Search based on names or record attributes\n* Paging and filters are supported\n* Match text to records, possibly identifying an organisation from existing data\n* Records are returned as typed structs (slightly different to the ROR JSON responses, but containing all the information)\n* Client ID authentication is supported and optional\n* (This is an early version and only contains the basics so far)\n\nThe top level `ROR` module contains functions for retrieving data from the API. Other ROR modules may not be needed at all.\nOther modules include:\n\n* `ROR.Client` presents a lower-level way to retrieve data, and returns maps based on the literal ROR JSON responses.\n* `ROR.Organization` contains a struct and utilities for the main ROR organization record\n* `ROR.Results` is an enumerable struct that contains both Organizations and metadata\n* `ROR.Matches` is another enumerable struct, which contains results from affiliation searches","ref":"readme.html#features"},{"type":"extras","title":"Examples - ROR","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Retrieving data about an organization using its ROR ID - ROR","doc":"```elixir\norg = ROR.get!(\"https://ror.org/04h699437\")\norg.domains\n# => [\"le.ac.uk\"],\n\n```","ref":"readme.html#retrieving-data-about-an-organization-using-its-ror-id"},{"type":"extras","title":"List ROR records, specifying a page and a filter - ROR","doc":"```elixir\nROR.list!(page: 15, filter: [type: :government])\n|> Enum.map(fn org -> org.id end)\n# => [\"https://ror.org/05m615h78\", \"https://ror.org/04wbxh769\",\n#     \"https://ror.org/04xh10z69\", \"https://ror.org/0127sq784\",\n#     \"https://ror.org/021c40092\", \"https://ror.org/00wyejx41\",\n#     \"https://ror.org/01q5ara80\", \"https://ror.org/05sej3528\",\n#     \"https://ror.org/024nbjg39\", \"https://ror.org/00n523x67\",\n#     \"https://ror.org/02zqy3981\", \"https://ror.org/0320bge18\",\n#     \"https://ror.org/02jcwf181\", \"https://ror.org/02m388s04\",\n#     \"https://ror.org/01r2man76\", \"https://ror.org/05335sh79\",\n#     \"https://ror.org/03hwfnp11\", \"https://ror.org/01wsx6q69\",\n#     \"https://ror.org/042jr0j26\", \"https://ror.org/03y255h89\"]\n```","ref":"readme.html#list-ror-records-specifying-a-page-and-a-filter"},{"type":"extras","title":"A quick search - ROR","doc":"```elixir\na = ROR.quick_search!(\"University of Manchester\")\n    |> Enum.take(1)\n    |> List.first()\na.established\n# => 1824\n\n```","ref":"readme.html#a-quick-search"},{"type":"extras","title":"An affiliation search for strong match or nil, also showing off the string conversion feature - ROR","doc":"```elixir\norg = ROR.chosen_organization!(\"CERN\")\nEnum.map(org.names, &to_string/1)\n# => [\"CERN\", \"European Organization for Nuclear Research\",\n#     \"Europäische Organisation für Kernforschung\",\n#     \"Organisation européenne pour la recherche nucléaire\"]\n\n```","ref":"readme.html#an-affiliation-search-for-strong-match-or-nil-also-showing-off-the-string-conversion-feature"},{"type":"extras","title":"Installation - ROR","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `ror` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ror, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"References - ROR","doc":"","ref":"readme.html#references"},{"type":"extras","title":"ROR Resources - ROR","doc":"* [ROR website](https://ror.org)\n* [ROR API Documentation](https://ror.readme.io/v2/docs/basics)\n* [Projects using ROR](https://airtable.com/app2Tnq1uCHnS8HQD/shrM876d6Koi1UONe/tbljRW9VeQOqY6oOg?backgroundColor=gray&viewControls=on)","ref":"readme.html#ror-resources"},{"type":"extras","title":"Documentation - ROR","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Contributing - ROR","doc":"You can request new features by creating an [issue](https://github.com/Digital-Identity-Labs/ror/issues),\nor submit a [pull request](https://github.com/Digital-Identity-Labs/ror/pulls) with your contribution.\n\nIf you are comfortable working with Python but ROR's Elixir code is unfamiliar then this blog post may help: \n[Elixir For Humans Who Know Python](https://hibox.live/elixir-for-humans-who-know-python)","ref":"readme.html#contributing"},{"type":"extras","title":"Copyright and License - ROR","doc":"Copyright (c) 2025 Digital Identity Ltd, UK\n\nThis software is MIT licensed.","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"Disclaimer - ROR","doc":"This Elixir ROR library is not endorsed by The Research Organization Registry (ROR)\n\nThis software may change considerably in the first few releases after 0.1.0 - it is not yet stable!","ref":"readme.html#disclaimer"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Digital Identity Labs\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}